aboutsummaryrefslogtreecommitdiff
path: root/src/main.cpp
diff options
context:
space:
mode:
authorRoss Nicoll <[email protected]>2015-08-01 11:44:25 +0100
committerJ Ross Nicoll <[email protected]>2015-10-31 14:49:39 +0000
commit5731f4f3c6dff84d6c5264954ba15e5b991abe38 (patch)
tree0e162847a682e9074ec7fd9598c3d28b4768b858 /src/main.cpp
parentIntroduce basic Dogecoin branding (diff)
downloaddiscoin-5731f4f3c6dff84d6c5264954ba15e5b991abe38.tar.xz
discoin-5731f4f3c6dff84d6c5264954ba15e5b991abe38.zip
Update Bitcoin references and addresses in strings to Dogecoin equivalents
Diffstat (limited to 'src/main.cpp')
-rw-r--r--src/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main.cpp b/src/main.cpp
index cddd30ff7..9325a2fdb 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -39,7 +39,7 @@
using namespace std;
#if defined(NDEBUG)
# error "Bitcoin cannot be compiled without assertions."
#endif
/**
@@ -90,7 +90,7 @@ static void CheckBlockIndex();
/** Constant stuff for coinbase transactions we create: */
CScript COINBASE_FLAGS;
-const string strMessageMagic = "Bitcoin Signed Message:\n";
+const string strMessageMagic = "Dogecoin Signed Message:\n";
// Internal stuff
namespace {
@@ -1732,7 +1732,7 @@ bool FindUndoPos(CValidationState &state, int nFile, CDiskBlockPos &pos, unsigne
static CCheckQueue<CScriptCheck> scriptcheckqueue(128);
void ThreadScriptCheck() {
- RenameThread("bitcoin-scriptch");
+ RenameThread("dogecoin-scriptch");
scriptcheckqueue.Thread();
}
@@ -39,7 +39,7 @@
using namespace std;
#if defined(NDEBUG)
-# error "Bitcoin cannot be compiled without assertions."
+# error "Dogecoin cannot be compiled without assertions."
#endif
/**